if(!self.define){let s,r={};const l=(l,n)=>(l=new URL(l+".js",n).href,r[l]||new Promise((r=>{if("document"in self){const s=document.createElement("script");s.src=l,s.onload=r,document.head.appendChild(s)}else s=l,importScripts(l),r()})).then((()=>{let s=r[l];if(!s)throw new Error(`Module ${l} didn’t register its module`);return s})));self.define=(n,e)=>{const i=s||("document"in self?document.currentScript.src:"")||location.href;if(r[i])return;let u={};const o=s=>l(s,i),f={module:{uri:i},exports:u,require:o};r[i]=Promise.all(n.map((s=>f[s]||o(s)))).then((s=>(e(...s),u)))}}define(["./workbox-db5fc017"],(function(s){"use strict";s.setCacheNameDetails({prefix:"dpgui"}),self.addEventListener("message",(s=>{s.data&&"SKIP_WAITING"===s.data.type&&self.skipWaiting()})),s.precacheAndRoute([{url:"/css/chunk-vendors.5c30036f.css",revision:null},{url:"/css/input.94751e2f.css",revision:null},{url:"/fonts/fa-brands-400.9a905705.ttf",revision:null},{url:"/fonts/fa-brands-400.b6033b54.woff2",revision:null},{url:"/fonts/fa-regular-400.3580b4a9.woff2",revision:null},{url:"/fonts/fa-regular-400.67a0fb74.ttf",revision:null},{url:"/fonts/fa-solid-900.6a8db53d.ttf",revision:null},{url:"/fonts/fa-solid-900.fd0b155c.woff2",revision:null},{url:"/fonts/fa-v4compatibility.e4efb16c.ttf",revision:null},{url:"/index.html",revision:"7325d696093741bf7918fec3d084cc9a"},{url:"/js/app.78a8b3d3.js",revision:null},{url:"/js/args10.94d2b279.js",revision:null},{url:"/js/args11.35039f9c.js",revision:null},{url:"/js/args14.f318b423.js",revision:null},{url:"/js/args15.56f0a576.js",revision:null},{url:"/js/args18.69c0f409.js",revision:null},{url:"/js/args19.8d35ef50.js",revision:null},{url:"/js/args2.59ecf3f9.js",revision:null},{url:"/js/args22.a7788c63.js",revision:null},{url:"/js/args24.51773cf0.js",revision:null},{url:"/js/args26.6658f321.js",revision:null},{url:"/js/args27.9e392433.js",revision:null},{url:"/js/args30.f6edc4da.js",revision:null},{url:"/js/args4.8f6a3f38.js",revision:null},{url:"/js/args6.772f56e9.js",revision:null},{url:"/js/args8.e139dd69.js",revision:null},{url:"/js/chunk-vendors.4d5ea4ae.js",revision:null},{url:"/js/input.8b746200.js",revision:null},{url:"/manifest.json",revision:"35da3532b61f3af0ef6237fd7837e92e"},{url:"/robots.txt",revision:"b6216d61c03e6ce0c9aea6ca7808f7ca"}],{})}));
//# sourceMappingURL=service-worker.js.map
