"use strict";(self["webpackChunkdpgui"]=self["webpackChunkdpgui"]||[]).push([[782],{9222:function(e){e.exports=JSON.parse('{"object":"Argument","name":"init_reaction_jdata","type":["dict"],"optional":false,"alias":[],"doc":"Generate initial data for reactive systems for small gas-phase molecules, from a ReaxFF NVT MD trajectory.","repeat":false,"sub_fields":{"type_map":{"object":"Argument","name":"type_map","type":["list"],"optional":false,"alias":[],"doc":"Type map, which should match types in the initial data. e.g. [\\"C\\", \\"H\\", \\"O\\"]","repeat":false,"sub_fields":{},"sub_variants":{}},"reaxff":{"object":"Argument","name":"reaxff","type":["dict"],"optional":false,"alias":[],"doc":"Parameters for ReaxFF NVT MD.","repeat":false,"sub_fields":{"data":{"object":"Argument","name":"data","type":["str"],"optional":false,"alias":[],"doc":"Path to initial LAMMPS data file. The atom_style should be charge.","repeat":false,"sub_fields":{},"sub_variants":{}},"ff":{"object":"Argument","name":"ff","type":["str"],"optional":false,"alias":[],"doc":"Path to ReaxFF force field file. Available in the lammps/potentials directory.","repeat":false,"sub_fields":{},"sub_variants":{}},"control":{"object":"Argument","name":"control","type":["str"],"optional":false,"alias":[],"doc":"Path to ReaxFF control file.","repeat":false,"sub_fields":{},"sub_variants":{}},"temp":{"object":"Argument","name":"temp","type":["int","float"],"optional":false,"alias":[],"doc":"Target Temperature for the NVT MD simulation. Unit: K.","repeat":false,"sub_fields":{},"sub_variants":{}},"dt":{"object":"Argument","name":"dt","type":["int","float"],"optional":false,"alias":[],"doc":"Real time for every time step. Unit: fs.","repeat":false,"sub_fields":{},"sub_variants":{}},"tau_t":{"object":"Argument","name":"tau_t","type":["int","float"],"optional":false,"alias":[],"doc":"Time to determine how rapidly the temperature. Unit: fs.","repeat":false,"sub_fields":{},"sub_variants":{}},"dump_freq":{"object":"Argument","name":"dump_freq","type":["int"],"optional":false,"alias":[],"doc":"Frequency of time steps to collect trajectory.","repeat":false,"sub_fields":{},"sub_variants":{}},"nstep":{"object":"Argument","name":"nstep","type":["int"],"optional":false,"alias":[],"doc":"Total steps to run the ReaxFF MD simulation.","repeat":false,"sub_fields":{},"sub_variants":{}}},"sub_variants":{}},"cutoff":{"object":"Argument","name":"cutoff","type":["float"],"optional":false,"alias":[],"doc":"Cutoff radius to take clusters from the trajectory. Note that only a complete molecule or free radical will be taken.","repeat":false,"sub_fields":{},"sub_variants":{}},"dataset_size":{"object":"Argument","name":"dataset_size","type":["int"],"optional":false,"alias":[],"doc":"Collected dataset size for each bond type.","repeat":false,"sub_fields":{},"sub_variants":{}},"qmkeywords":{"object":"Argument","name":"qmkeywords","type":["str"],"optional":false,"alias":[],"doc":"Gaussian keywords for first-principle calculations. e.g. force mn15/6-31g** Geom=PrintInputOrient. Note that \\"force\\" job is necessary to collect data. Geom=PrintInputOrient should be used when there are more than 50 atoms in a cluster.","repeat":false,"sub_fields":{},"sub_variants":{}}},"sub_variants":{}}')}}]);