"use strict";(self["webpackChunkdpgui"]=self["webpackChunkdpgui"]||[]).push([[59],{634:function(e){e.exports=JSON.parse('{"object":"Argument","name":"task","type":["dict"],"optional":false,"alias":[],"doc":"","repeat":false,"sub_fields":{"command":{"object":"Argument","name":"command","type":["str"],"optional":false,"alias":[],"doc":"A command to be executed of this task. The expected return code is 0.","repeat":false,"sub_fields":{},"sub_variants":{}},"task_work_path":{"object":"Argument","name":"task_work_path","type":["str"],"optional":false,"alias":[],"doc":"The dir where the command to be executed.","repeat":false,"sub_fields":{},"sub_variants":{}},"forward_files":{"object":"Argument","name":"forward_files","type":["list"],"optional":false,"alias":[],"doc":"The files to be uploaded in task_work_path before the task exectued.","repeat":false,"sub_fields":{},"sub_variants":{}},"backward_files":{"object":"Argument","name":"backward_files","type":["list"],"optional":false,"alias":[],"doc":"The files to be download to local_root in task_work_path after the task finished","repeat":false,"sub_fields":{},"sub_variants":{}},"outlog":{"object":"Argument","name":"outlog","type":["str","NoneType"],"optional":false,"alias":[],"doc":"The out log file name. redirect from stdout","repeat":false,"sub_fields":{},"sub_variants":{}},"errlog":{"object":"Argument","name":"errlog","type":["str","NoneType"],"optional":false,"alias":[],"doc":"The err log file name. redirect from stderr","repeat":false,"sub_fields":{},"sub_variants":{}}},"sub_variants":{}}')}}]);